@@ -30,7 +30,7 @@ from reddcolors import Palette
 from .model_repo import *
 from .unmodel_repo import *
 from .block import ReddModel
-from .utils import fold_dataframe, nullify_output, flatten
+from .utils import fold_dataframe, nullify_output, flatten, get_support
 
 
 rc = Palette()
@@ -338,7 +338,7 @@ def plot_KeplerianModel(my_data, my_model, res, saveloc='', options=None):
         temp_dat_names.append('{}/temp/temp_data{}.csv'.format(saveloc, tail_x))
 
         with open(temp_script, 'w') as f:
-            f.write(open('support/init.scr').read())
+            f.write(open(get_support('init.scr')).read())
             # DEPENDENCIES
             f.write('''
 import kepler
